@@ -2,6 +2,7 @@ import eccodes
 import numcodecs
 from numcodecs.compat import ndarray_copy, ensure_contiguous_ndarray
 
+
 class RawGribCodec(numcodecs.abc.Codec):
     codec_id = "gribscan.rawgrib"
 
@@ -18,14 +19,7 @@ class RawGribCodec(numcodecs.abc.Codec):
         if hasattr(data, "build_array"):
             data = data.build_array()
 
-
         if out is not None:
             return ndarray_copy(data, out)
         else:
             return data
-
-def register():
-    numcodecs.register_codec(RawGribCodec, "rawgrib")
-    numcodecs.register_codec(RawGribCodec)
-
-register()
